# Sketcher

Sketcher commands are used to define the entities, such as the geometry, constraints, and dimensions, to create a sketch and to store the values and attributes associated with a particular sketch.

## Create constrained sketches

```{eval-rst}
.. autoclass:: abaqus.Sketcher.SketchModel.SketchModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Classes

### ConstrainedSketch

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketch.ConstrainedSketch
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConstrainedSketchConstraintModel

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.ConstrainedSketchConstraintModel.ConstrainedSketchConstraintModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConstrainedSketchDimensionModel

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchDimension.ConstrainedSketchDimensionModel.ConstrainedSketchDimensionModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConstrainedSketchGeometryModel

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.ConstrainedSketchGeometryModel.ConstrainedSketchGeometryModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConstrainedSketchParameterModel

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchParameter.ConstrainedSketchParameterModel.ConstrainedSketchParameterModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConstrainedSketchVertexModel

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchVertex.ConstrainedSketchVertexModel.ConstrainedSketchVertexModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

### CoincidentConstraint

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.CoincidentConstraint.CoincidentConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConcentricConstraint

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.ConcentricConstraint.ConcentricConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConstrainedSketchConstraint

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.ConstrainedSketchConstraint.ConstrainedSketchConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### EqualDistanceConstraint

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.EqualDistanceConstraint.EqualDistanceConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### EqualLengthConstraint

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.EqualLengthConstraint.EqualLengthConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### EqualRadiusConstraint

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.EqualRadiusConstraint.EqualRadiusConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### FixedConstraint

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.FixedConstraint.FixedConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### HorizontalConstraint

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.HorizontalConstraint.HorizontalConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ParallelConstraint

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.ParallelConstraint.ParallelConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### PerpendicularConstraint

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.PerpendicularConstraint.PerpendicularConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TangentConstraint

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.TangentConstraint.TangentConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### VerticalConstraint

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.VerticalConstraint.VerticalConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

### AngularDimension

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchDimension.AngularDimension.AngularDimension
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DistanceDimension

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchDimension.DistanceDimension.DistanceDimension
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### HorizontalDimension

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchDimension.HorizontalDimension.HorizontalDimension
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ObliqueDimension

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchDimension.ObliqueDimension.ObliqueDimension
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### RadialDimension

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchDimension.RadialDimension.RadialDimension
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### VerticalDimension

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchDimension.VerticalDimension.VerticalDimension
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConstrainedSketchGeometry

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.ConstrainedSketchGeometry.ConstrainedSketchGeometry
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConstrainedSketchGeometryArray

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.ConstrainedSketchGeometryArray.ConstrainedSketchGeometryArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Arc3Points

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.Arc3Points.Arc3Points
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ArcByCenterEnds

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.ArcByCenterEnds.ArcByCenterEnds
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ArcByStartEndTangent

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.ArcByStartEndTangent.ArcByStartEndTangent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### CircleByCenterPerimeter

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.CircleByCenterPerimeter.CircleByCenterPerimeter
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConstructionCircleByCenterPerimeter

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.ConstructionCircleByCenterPerimeter.ConstructionCircleByCenterPerimeter
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConstructionLine

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.ConstructionLine.ConstructionLine
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### EllipseByCenterPerimeter

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.EllipseByCenterPerimeter.EllipseByCenterPerimeter
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### FilletByRadius

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.FilletByRadius.FilletByRadius
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### getPointAtDistance

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.getPointAtDistance.getPointAtDistance
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Line

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.Line.Line
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Spline

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.Spline.Spline
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Spot

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.Spot.Spot
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

### ConstrainedSketcherOptions

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchOptions.ConstrainedSketcherOptions.ConstrainedSketcherOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConstrainedSketchImageOptions

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchOptions.ConstrainedSketchImageOptions.ConstrainedSketchImageOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConstrainedSketchOptions

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchOptions.ConstrainedSketchOptions.ConstrainedSketchOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Parameter

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchParameter.Parameter.Parameter
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

### ConstrainedSketchVertex

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchVertex.ConstrainedSketchVertex.ConstrainedSketchVertex
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConstrainedSketchVertexArray

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchVertex.ConstrainedSketchVertexArray.ConstrainedSketchVertexArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Spot

```{eval-rst}
.. autoclass:: abaqus.Sketcher.ConstrainedSketchVertex.Spot.Spot
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

% This is a comment ro supress the warning "(ERROR/3) Document may not end with a transition."
